@@ -17,8 +17,8 @@ class Migration(migrations.Migration):
                 ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                 ('messageId', models.TextField(max_length=2048)),
                 ('message', models.TextField(default=b'')),
-                ('contact', models.ForeignKey(to='newsletter.Contact')),
-                ('newsletter', models.ForeignKey(to='newsletter.Newsletter')),
+                ('contact', models.ForeignKey(to='newsletter.Contact', on_delete=models.CASCADE)),
+                ('newsletter', models.ForeignKey(to='newsletter.Newsletter', on_delete=models.CASCADE)),
             ],
         ),
         migrations.CreateModel(
@@ -26,7 +26,7 @@ class Migration(migrations.Migration):
             fields=[
                 ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                 ('sync', models.BooleanField(default=True)),
-                ('newsletter', models.ForeignKey(to='newsletter.Newsletter', unique=True)),
+                ('newsletter', models.ForeignKey(to='newsletter.Newsletter', unique=True, on_delete=models.CASCADE)),
             ],
         ),
     ]
